@@ -1,50 +1,4 @@
-# Specify undefined global variables for R CMD check
-utils::globalVariables(c("shape", "size", "text", ":="))
-
-#the class definition
-InputHeatmap<-setClass(
-	"InputHeatmap",  
-	slots = list(
-		input = "list", 
-		data = "tbl",
-		palette_discrete = "list", 
-		palette_continuous = "list",
-		group_top_annotation = "list",
-		group_left_annotation = "list",
-		top_annotation = "tbl",
-		left_annotation = "tbl",
-		arguments = "list" ,
-		layer_symbol = "tbl",
-		layer_text = "tbl"
-	),
-	prototype=list(
-		palette_discrete=
-			list(
-				brewer.pal(9, "Set1"),
-				brewer.pal(8, "Set2"),
-				brewer.pal(12, "Set3"),
-				brewer.pal(8, "Dark2"),
-				brewer.pal(8, "Accent"),
-				brewer.pal(8, "Pastel2")
-			), 
-		palette_continuous=
-			list(
-				brewer.pal(11, "Spectral") |> rev(),
-				viridis(n = 5),
-				magma(n = 5),
-				brewer.pal(11, "PRGn"),
-				brewer.pal(11, "BrBG")
-			),
-		input = list(),
-		top_annotation =  tibble(col_name = character(), orientation = character(), col_orientation = character(), data = list(),      fx = list(),    annot = list(),     annot_type= character(),   idx = integer(), color = list(), further_arguments = list()),
-		left_annotation = tibble(col_name = character(), orientation = character(), col_orientation = character(), data = list(),      fx = list(),    annot = list(),     annot_type= character(),   idx = integer(), color = list(), further_arguments = list()),
-		group_top_annotation = list(),
-		group_left_annotation = list(),
-		layer_symbol = tibble(column = integer(), row = integer(), shape = integer()),
-		layer_text = tibble(column = integer(), row = integer(), text = character(), size = numeric())
-		
-	)
-)
+# Methods for InputHeatmap class
 
 
 #' Creates a  `ComplexHeatmap` object for less standard plot manipulation (e.g. changing legend position)
@@ -199,7 +153,11 @@ setMethod("show", "InputHeatmap", function(object){
 })
 
 
-#' @rdname plot_arithmetic
+#' Add two tidyHeatmap objects together
+#' 
+#' @param e1 First tidyHeatmap object
+#' @param e2 Second tidyHeatmap object
+#' @return A combined ComplexHeatmap object
 #' 
 #' @importFrom ComplexHeatmap add_heatmap
 #' 
@@ -243,7 +201,7 @@ setMethod("show", "InputHeatmap", function(object){
 #' 
 #' @details This function takes a tbl as an input and creates a `ComplexHeatmap` plot. The information is stored in a `InputHeatmap` object that is updated along the pipe statement, for example adding annotation layers. 
 #'
-#' @return A `InputHeatmap` objects that gets evaluated to a `ComplexHeatmap` object
+#' @return An `InputHeatmap` object that gets evaluated to a `ComplexHeatmap`
 #'
 #'
 #'
@@ -265,6 +223,16 @@ setMethod("show", "InputHeatmap", function(object){
 #' @references Mangiola, S. and Papenfuss, A.T., 2020. "tidyHeatmap: an R package for 
 #'   modular heatmap production based on tidy principles." Journal of Open Source Software.
 #'   doi:10.21105/joss.02472.
+#' @param .data A `tbl_df` formatted as | <ELEMENT> | <FEATURE> | <VALUE> | <...> |
+#' @param .row The name of the column to use as rows
+#' @param .column The name of the column to use as columns  
+#' @param .value The name of the column to use as values
+#' @param transform A function to transform the data (optional)
+#' @param scale One of "none", "row", "column", or "both" for scaling
+#' @param palette_value A character vector of colors or a function for value colors
+#' @param palette_grouping A list of color palettes for grouping annotations
+#' @param .scale DEPRECATED: Use scale instead
+#' @param ... Additional arguments passed to ComplexHeatmap
 #' @source [Mangiola and Papenfuss., 2020](https://joss.theoj.org/papers/10.21105/joss.02472)
 setGeneric("heatmap", function(.data,
 															 .row, 
@@ -280,7 +248,6 @@ setGeneric("heatmap", function(.data,
 															 ...) standardGeneric("heatmap"))
 
 #' Creates a  `InputHeatmap` object from `tbl_df` on evaluation creates a `ComplexHeatmap`
-#' @inheritParams heatmap
 #' 
 #' @docType methods
 #' @rdname heatmap-method
@@ -370,7 +337,7 @@ heatmap_ <-
 #' @rdname heatmap-method
 #' 
 #' @return A `InputHeatmap` object
-#'
+#' 
 setMethod("heatmap", "tbl", heatmap_)
 
 #' Creates a  `InputHeatmap` object from `tbl_df` on evaluation creates a `ComplexHeatmap`
@@ -1530,5 +1497,204 @@ setMethod("save_pdf", "Heatmap", .save_pdf)
 #' @param units	A character string. units ("in", "cm", or "mm")
 setMethod("save_pdf", "InputHeatmap", .save_pdf)
 
+#' Add group annotation strips to a tidyHeatmap
+#'
+#' @description `annotation_group()` adds group annotation strips to a tidyHeatmap object, 
+#' allowing you to visually group rows or columns based on categorical variables. This is 
+#' useful for highlighting biological or experimental groups in your heatmap.
+#'
+#' @param .data A tidyHeatmap object
+#' @param ... Grouping columns (unquoted, like dplyr::group_by)
+#' @param palette_grouping List of color vectors for each grouping. Each element should be 
+#'   a vector of colors for the corresponding grouping variable.
+#' @param group_label_fontsize Font size for group labels
+#' @param show_group_name Logical, show the group annotation name
+#' @param group_strip_height Height of group strip as a grid unit (default: 9pt)
+#' @return A tidyHeatmap object with group annotation strips added
+#' 
+#' @examples
+#' 
+#' # Basic usage with row grouping
+#' tidyHeatmap::N52 |>
+#'   tidyHeatmap::heatmap(
+#'     .row = symbol_ct,
+#'     .column = UBR,
+#'     .value = `read count normalised log`
+#'   ) |>
+#'   annotation_group(CAPRA_TOTAL)
+#' 
+#' # With custom colors and formatting
+#' tidyHeatmap::N52 |>
+#'   tidyHeatmap::heatmap(
+#'     .row = symbol_ct,
+#'     .column = UBR,
+#'     .value = `read count normalised log`
+#'   ) |>
+#'   annotation_group(
+#'     CAPRA_TOTAL,
+#'     palette_grouping = list(c("#E64B35", "#4DBBD5")),
+#'     group_label_fontsize = 10,
+#'     show_group_name = FALSE
+#'   )
+#' 
+#' # Multiple grouping variables
+#' tidyHeatmap::N52 |>
+#'   tidyHeatmap::heatmap(
+#'     .row = symbol_ct,
+#'     .column = UBR,
+#'     .value = `read count normalised log`
+#'   ) |>
+#'   annotation_group(
+#'     CAPRA_TOTAL, 
+#'     `Cell type`,
+#'     palette_grouping = list(
+#'       c("#E64B35", "#4DBBD5"),  # colors for CAPRA_TOTAL
+#'       c("#00A087", "#F39B7F")   # colors for Cell type
+#'     )
+#'   )
+#' 
+#' @export
+#' @references Mangiola, S. and Papenfuss, A.T., 2020. "tidyHeatmap: an R package for 
+#'   modular heatmap production based on tidy principles." Journal of Open Source Software.
+#'   doi:10.21105/joss.02472.
+#' @source [Mangiola and Papenfuss., 2020](https://joss.theoj.org/papers/10.21105/joss.02472)
+setGeneric("annotation_group", function(.data, ...) standardGeneric("annotation_group"))
+
+#' @export
+#' @rdname annotation_group
+setMethod("annotation_group", "InputHeatmap", function(
+  .data,
+  ...,
+  palette_grouping = list(),
+  group_label_fontsize = 8,
+  show_group_name = TRUE,
+  group_strip_height = grid::unit(9, "pt")
+) {
+  group_vars <- rlang::enquos(...)
+  if (length(group_vars) > 0) {
+    .data@data <- dplyr::group_by(.data@data, !!!group_vars)
+    .data@arguments$group_vars <- group_vars
+  }
+  .data@arguments$palette_grouping <- palette_grouping
+  .data@arguments$group_label_fontsize <- group_label_fontsize
+  .data@arguments$show_group_name <- show_group_name
+  .data@arguments$group_strip_height <- group_strip_height
+
+  add_grouping(.data)
+})
+
+#' Retrieve heatmap data and dendrograms as plotted
+#'
+#' \lifecycle{maturing}
+#'
+#' @description get_heatmap_data() extracts the heatmap matrix as it appears in the plot along with the row and column dendrograms, all with consistent naming.
+#'
+#' @importFrom ComplexHeatmap draw row_order column_order row_dend column_dend
+#'
+#' @name get_heatmap_data
+#' @rdname get_heatmap_data-method
+#'
+#' @param .data A `InputHeatmap` object from tidyHeatmap::heatmap()
+#'
+#' @details This function converts the InputHeatmap to ComplexHeatmap, draws it to perform clustering, then extracts the ordered matrix and dendrograms exactly as they appear in the heatmap plot.
+#' 
+#' @return A list containing:
+#' \itemize{
+#'   \item matrix: The abundance matrix with rows and columns ordered as in the heatmap
+#'   \item row_dend: The row dendrogram object
+#'   \item column_dend: The column dendrogram object
+#' }
+#'
+#' @examples
+#'
+#' hm <- tidyHeatmap::N52 |>
+#'   tidyHeatmap::heatmap(
+#'     .row = symbol_ct,
+#'     .column = UBR,
+#'     .value = `read count normalised log`
+#'   ) |>
+#'   annotation_group(
+#'     CAPRA_TOTAL,
+#'     palette_grouping = list(c("#E64B35", "#4DBBD5")),
+#'     group_label_fontsize = 10,
+#'     show_group_name = FALSE
+#'   )
+#' 
+#' # Multiple grouping variables
+#' tidyHeatmap::N52 |>
+#'   tidyHeatmap::heatmap(
+#'     .row = symbol_ct,
+#'     .column = UBR,
+#'     .value = `read count normalised log`
+#'   ) |>
+#'   annotation_group(
+#'     CAPRA_TOTAL, 
+#'     `Cell type`,
+#'     palette_grouping = list(
+#'       c("#E64B35", "#4DBBD5"),  # colors for CAPRA_TOTAL
+#'       c("#00A087", "#F39B7F")   # colors for Cell type
+#'     )
+#'   )
+#' 
+#' # Get heatmap data as plotted
+#' result <- hm |> get_heatmap_data()
+#' ordered_matrix <- result$matrix
+#' row_dendrogram <- result$row_dend
+#' column_dendrogram <- result$column_dend
+#'
+#' @export
+#' @references Mangiola, S. and Papenfuss, A.T., 2020. "tidyHeatmap: an R package for 
+#'   modular heatmap production based on tidy principles." Journal of Open Source Software.
+#'   doi:10.21105/joss.02472.
+#' @source [Mangiola and Papenfuss., 2020](https://joss.theoj.org/papers/10.21105/joss.02472)
+setGeneric("get_heatmap_data", function(.data) standardGeneric("get_heatmap_data"))
+
+#' get_heatmap_data
+#' 
+#' @docType methods
+#' @rdname get_heatmap_data-method
+#' 
+#' @return A list containing the ordered matrix, row dendrogram, and column dendrogram
+#'
+setMethod("get_heatmap_data", "InputHeatmap", function(.data) {
+	
+	# Convert to ComplexHeatmap and draw it
+	ch <- .data |> as_ComplexHeatmap()
+	ch_drawn <- ComplexHeatmap::draw(ch)
+	
+	# Get row and column orders
+	row_ord <- ComplexHeatmap::row_order(ch_drawn)
+	col_ord <- ComplexHeatmap::column_order(ch_drawn)
+	
+	# Get the abundance matrix from the original object
+	abundance_mat <- .data@input[[1]]
+	
+	# Handle grouped heatmaps (row_ord and col_ord might be lists) vs regular heatmaps
+	if (is.list(row_ord)) {
+		# For grouped heatmaps, concatenate all group orders and remove names
+		row_ord <- as.integer(unlist(row_ord))
+	}
+	if (is.list(col_ord)) {
+		# For grouped heatmaps, concatenate all group orders and remove names
+		col_ord <- as.integer(unlist(col_ord))
+	}
+	
+	# Create ordered matrix with consistent row and column names
+	ordered_matrix <- abundance_mat[row_ord, col_ord]
+	
+	# Get dendrograms
+	row_dendrogram <- ComplexHeatmap::row_dend(ch_drawn)
+	column_dendrogram <- ComplexHeatmap::column_dend(ch_drawn)
+	
+
+	
+	return(list(
+		matrix = ordered_matrix,
+		row_dend = row_dendrogram,
+		column_dend = column_dendrogram
+	))
+
+})
+
 
 
