@@ -1,10 +1,9 @@
-
-
 #' This is a generalisation of ifelse that accepts an object and return an objects
 #'
 #' @import dplyr
 #' @import tidyr
 #' @importFrom purrr as_mapper
+#' @importFrom tidyr replace_na
 #'
 #' @param .x A tibble
 #' @param .p A boolean
@@ -679,6 +678,17 @@ get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation
     df %>%
     mutate( data = map2(col_name,  col_orientation, ~ return_factor_ordering_by_col_or_row_names(!!.data_, .x, .y) ) ) 
   
+  # Check and handle NA/NaN values in data before processing
+  df = df %>%
+    mutate(data = map(data, ~ {
+      if (length(.x) > 0 && any(is.na(.x) | is.nan(.x))) {
+        warning("tidyHeatmap says: You have NA/NaN values in your annotation data. These will be replaced with 'NA'.")
+        replace_na(.x, "NA")
+      } else {
+        .x
+      }
+    }))
+  
   df = df %>%
 	    
 	  # Add function
@@ -733,12 +743,6 @@ get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation
   
   df = df %>%
 	  
-	  # # Check if NA in annotations
-	  # mutate_at(vars(!!annotation), function(x) {
-	  # 	if(any(is.na(x))) { warning("tidyHeatmap says: You have NAs into your annotation column"); replace_na(x, "NA"); } 
-	  # 	else { x } 
-	  # } ) %>% 
-	  
 		# Add color indexes separately for each orientation
 		mutate(annot_type = map_chr(annot, ~ .x %>% when(class(.) %in% c("factor", "character", "logical") ~ "discrete",
 																										class(.) %in% c("integer", "numerical", "numeric", "double") ~ "continuous",
@@ -813,7 +817,13 @@ get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation
 #' @importFrom grid unit
 #' @importFrom ComplexHeatmap anno_block
 #' @importFrom rlang set_names
-get_group_annotation = function(.data, .column, .row, .abundance, palette_annotation){
+#' @importFrom stats setNames
+get_group_annotation = function(
+  .data, .column, .row, .abundance, palette_annotation,
+  group_label_fontsize = 8,
+  show_group_name = TRUE,
+  group_strip_height = unit(9, "pt")
+) {
   
   # Comply with CRAN NOTES
   data = NULL
@@ -868,6 +878,12 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
       arrange(!!.row) %>%
       pull(!!as.symbol(x_y_annotation_cols$row))
     
+    # Handle NA/NaN values in row_split
+    if (any(is.na(row_split) | is.nan(row_split))) {
+      warning("tidyHeatmap says: You have NA/NaN values in your row grouping column. These will be replaced with 'NA'.")
+      row_split = replace_na(row_split, "NA")
+    }
+    
     # Create array of colours
     palette_fill_row = 
       colorRampPalette(
@@ -887,14 +903,18 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
     palette_text_row =  if_else(palette_fill_row %in% c("#FFFFFF", "white"), "#161616", "#ffffff")
   
     left_annotation_args = 
-      list(
-        ct = anno_block(  
-          gp = gpar(fill = palette_fill_row ),
-          labels = row_split %>% unique %>% sort,
-          labels_gp = gpar(col = palette_text_row, fontsize = 8),
-          which = "row",
-          width = unit(9, "pt")
-        )
+      setNames(
+        list(
+          anno_block(  
+            gp = gpar(fill = palette_fill_row ),
+            labels = row_split %>% unique %>% sort,
+            labels_gp = gpar(col = palette_text_row, fontsize = group_label_fontsize),
+            which = "row",
+            width = group_strip_height,
+            show_name = show_group_name
+          )
+        ),
+        x_y_annotation_cols$row
       )
     
     left_annotation = as.list(left_annotation_args)
@@ -913,6 +933,12 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
         arrange(!!.column) %>%
         pull(!!as.symbol(x_y_annotation_cols$column))
       
+      # Handle NA/NaN values in col_split
+      if (any(is.na(col_split) | is.nan(col_split))) {
+        warning("tidyHeatmap says: You have NA/NaN values in your column grouping column. These will be replaced with 'NA'.")
+        col_split = replace_na(col_split, "NA")
+      }
+      
       # Create array of colours
       palette_fill_column = 
         colorRampPalette(
@@ -933,14 +959,18 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
       
       
       top_annotation_args = 
-        list(
-          ct = anno_block(  
-            gp = gpar(fill = palette_fill_column ),
-            labels = col_split %>% unique %>% sort,
-            labels_gp = gpar(col = palette_text_column, fontsize = 8),
-            which = "column",
-            height = unit(9, "pt")
-          )
+        setNames(
+          list(
+            anno_block(  
+              gp = gpar(fill = palette_fill_column ),
+              labels = col_split %>% unique %>% sort,
+              labels_gp = gpar(col = palette_text_column, fontsize = group_label_fontsize),
+              which = "column",
+              height = group_strip_height,
+              show_name = show_group_name
+            )
+          ),
+          x_y_annotation_cols$column
         )
       
        top_annotation = as.list(top_annotation_args)
